@@ -46,7 +46,7 @@ __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.5.2"
+__version__ = "1.5.3"
 
 import base64
 import cgi
@@ -398,12 +398,15 @@ class DeliciousAPI(object):
             except TypeError:
                 pass
             try:
-                document.title = urlinfo['title']
+                document.title = urlinfo['title'] or u""
             except KeyError:
                 pass
             try:
-                top_tags = urlinfo['top_tags']
-                document.top_tags = sorted(top_tags.iteritems(), key=itemgetter(1), reverse=True)
+                top_tags = urlinfo['top_tags'] or {}
+                if top_tags:
+                    document.top_tags = sorted(top_tags.iteritems(), key=itemgetter(1), reverse=True)
+                else:
+                    document.top_tags = []
             except KeyError:
                 pass
             try:
